use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007000
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
invocant
dist
David
Golden
dagolden
Ricardo
Signes
rjbs
and
Ed
mohawk2
Karen
Etheridge
ether
Leon
Timmermans
fawaka
robario
webmaster
lib
CPAN
Meta
Requirements
